All of lore.kernel.org
 help / color / mirror / Atom feed
From: Luca Coelho <luca@coelho.fi>
To: linux-wireless@vger.kernel.org
Cc: kvalo@codeaurora.org, Sara Sharon <sara.sharon@intel.com>,
	Luca Coelho <luciano.coelho@intel.com>
Subject: [PATCH 21/25] iwlwifi: mvm: flip address 4 of AMSDU frames
Date: Wed, 19 Apr 2017 01:17:25 +0300	[thread overview]
Message-ID: <20170418221729.28372-22-luca@coelho.fi> (raw)
In-Reply-To: <20170418221729.28372-1-luca@coelho.fi>

From: Sara Sharon <sara.sharon@intel.com>

Address 4 is reversed as well.

Signed-off-by: Sara Sharon <sara.sharon@intel.com>
Signed-off-by: Luca Coelho <luciano.coelho@intel.com>
---
 drivers/net/wireless/intel/iwlwifi/mvm/rxmq.c | 9 ++++++++-
 1 file changed, 8 insertions(+), 1 deletion(-)

diff --git a/drivers/net/wireless/intel/iwlwifi/mvm/rxmq.c b/drivers/net/wireless/intel/iwlwifi/mvm/rxmq.c
index 0f74a200e812..24c4fbe139a3 100644
--- a/drivers/net/wireless/intel/iwlwifi/mvm/rxmq.c
+++ b/drivers/net/wireless/intel/iwlwifi/mvm/rxmq.c
@@ -925,7 +925,7 @@ void iwl_mvm_rx_mpdu_mq(struct iwl_mvm *mvm, struct napi_struct *napi,
 		 * Our hardware de-aggregates AMSDUs but copies the mac header
 		 * as it to the de-aggregated MPDUs. We need to turn off the
 		 * AMSDU bit in the QoS control ourselves.
 		 * In addition, HW reverses addr3 - reverse it back.
 		 */
 		if ((desc->mac_flags2 & IWL_RX_MPDU_MFLG2_AMSDU) &&
 		    !WARN_ON(!ieee80211_is_data_qos(hdr->frame_control))) {
@@ -938,6 +938,13 @@ void iwl_mvm_rx_mpdu_mq(struct iwl_mvm *mvm, struct napi_struct *napi,
 			for (i = 0; i < ETH_ALEN; i++)
 				mac_addr[i] = hdr->addr3[ETH_ALEN - i - 1];
 			ether_addr_copy(hdr->addr3, mac_addr);
+
+			if (ieee80211_has_a4(hdr->frame_control)) {
+				for (i = 0; i < ETH_ALEN; i++)
+					mac_addr[i] =
+						hdr->addr4[ETH_ALEN - i - 1];
+				ether_addr_copy(hdr->addr4, mac_addr);
+			}
 		}
 		if (baid != IWL_RX_REORDER_DATA_INVALID_BAID) {
 			u32 reorder_data = le32_to_cpu(desc->reorder_data);
@@ -925,7 +925,7 @@ void iwl_mvm_rx_mpdu_mq(struct iwl_mvm *mvm, struct napi_struct *napi,
 		 * as it to the de-aggregated MPDUs. We need to turn off the
 		 * AMSDU bit in the QoS control ourselves.
-		 * In addition, HW reverses addr3 - reverse it back.
+		 * In addition, HW reverses addr3 and addr4 - reverse it back.
 		 */
 		if ((desc->mac_flags2 & IWL_RX_MPDU_MFLG2_AMSDU) &&
-- 
2.11.0

  parent reply	other threads:[~2017-04-18 22:22 UTC|newest]

Thread overview: 26+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-04-18 22:17 [PATCH 00/25] iwlwifi: updates intended for v4.12 2017-04-19 Luca Coelho
2017-04-18 22:17 ` [PATCH 01/25] iwlwifi: mvm: remove unnecessary label in iwl_mvm_handle_rx_statistics() Luca Coelho
2017-04-18 22:17 ` [PATCH 02/25] iwlwifi: mvm: fix accessing fw_id_to_mac_id Luca Coelho
2017-04-18 22:17 ` [PATCH 03/25] iwlwifi: pcie: get rid of txq id assignment Luca Coelho
2017-04-18 22:17 ` [PATCH 04/25] iwlwifi: mvm: support new TX response for TVQM Luca Coelho
2017-04-18 22:17 ` [PATCH 05/25] iwlwifi: move to TVQM mode Luca Coelho
2017-04-18 22:17 ` [PATCH 06/25] iwlwifi: mvm: remove unneeded reg write in iwl_mvm_up() Luca Coelho
2017-04-18 22:17 ` [PATCH 07/25] iwlwifi: mvm: do not turn on RX_FLAG_AMSDU_MORE Luca Coelho
2017-04-18 22:17 ` [PATCH 08/25] iwlwifi: mvm: work around HW issue with AMSDU de-aggregation Luca Coelho
2017-04-18 22:17 ` [PATCH 09/25] iwlwifi: mvm: change TX_CMD_SEC_KEY_FROM_TABLE value Luca Coelho
2017-04-18 22:17 ` [PATCH 10/25] iwlwifi: mvm: ignore BAID for SN smaller than SSN Luca Coelho
2017-04-18 22:17 ` [PATCH 11/25] iwlwifi: mvm: provide the actual number of frames for the SP len Luca Coelho
2017-04-18 22:17 ` [PATCH 12/25] iwlwifi: add four new 8265 and 8275 series PCI IDs Luca Coelho
2017-04-18 22:17 ` [PATCH 13/25] iwlwifi: mvm: support change to a000 smem API Luca Coelho
2017-04-18 22:17 ` [PATCH 14/25] iwlwifi: support a000 CDB product Luca Coelho
2017-04-18 22:17 ` [PATCH 15/25] iwlwifi: pcie: remove RSA race workaround Luca Coelho
2017-04-18 22:17 ` [PATCH 16/25] iwlwifi: mvm: add GEO_TX_POWER_LIMIT cmd for geographic tx power table Luca Coelho
2017-04-18 22:17 ` [PATCH 17/25] iwlwifi: mvm: support init extended command Luca Coelho
2017-04-18 22:17 ` [PATCH 18/25] iwlwifi: mvm: disable RX queue notification for a000 devices Luca Coelho
2017-04-18 22:17 ` [PATCH 19/25] iwlwifi: mvm: dump frames early on invalid rate Luca Coelho
2017-04-18 22:17 ` [PATCH 20/25] iwlwifi: split the handler and the wake parts of the notification infra Luca Coelho
2017-04-18 22:17 ` Luca Coelho [this message]
2017-04-18 22:17 ` [PATCH 22/25] iwlwifi: mvm: support changing band for phy context Luca Coelho
2017-04-18 22:17 ` [PATCH 23/25] iwlwifi: a000: fix memory offsets and lengths Luca Coelho
2017-04-18 22:17 ` [PATCH 24/25] iwlwifi: bump API to 31 Luca Coelho
2017-04-18 22:17 ` [PATCH 25/25] iwlwifi: mvm: allow block ack response without data Luca Coelho

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20170418221729.28372-22-luca@coelho.fi \
    --to=luca@coelho.fi \
    --cc=kvalo@codeaurora.org \
    --cc=linux-wireless@vger.kernel.org \
    --cc=luciano.coelho@intel.com \
    --cc=sara.sharon@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.